---
title: 워드프레스 지원 결제대행사
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 플러그인
seo:
  title: 워드프레스 지원 결제대행사
  description: >-
    우커머스 플러그인으로 웹사이트 구축 시 이용 가능한 PG사 및 연동방식 참고를 위한 정보입니다. 포트원에서 지원하고 있는 워드프레스
    결제대행사 내용을 확인하세요.
  keywords:
    - 워드프레스
tags:
  - 공통
  - 플러그인
  - 워드프레스
pgCompanies:
  - 공통
searchTags:
  - 단비스토어
  - 코스모스팜
  - 워드프레스
  - 플러그인
  - 우커머스
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="워드프레스 우커머스 플러그인으로 웹사이트를 구축하시는 경우
이용 가능한 결제대행사와 연동방식이 구분되어있으니 참고하여 이용 부탁 드립니다.
" />

포트원에서 현재 지원이 가능한 결제플러그인은 우커머스 플러그인입니다.

#### **정기결제 이용시 참고사항**

정기결제는 [우커머스 서브스크립션(subscription) 플러그인↗](https://woo.com/products/woocommerce-subscriptions/) 을 기반으로 서비스를 제공드리고 있어 우커머스에서 제공하는 WooCommerce Subscriptions 플러그인(유료, $199)이 반드시 설치되어 있어야 합니다.

#### **본인인증 이용시 참고사항**

워드프레스로 구축된 사이트의 본인인증서비스는 ‘포트원’에서 지원되지 않아 포트원 기반의 본인인증 서비스를 지원하는 타사 플러그인을 이용해주시길 권장드립니다.

- [코스모스팜 회원관리↗](https://www.cosmosfarm.com/wpstore/product/cosmosfarm-members) : 다날의  SMS본인인증 지원
- [단비스토어 얼티밋멤버↗](https://staging-danbistoretk.kinsta.cloud/product/um-verification/) : 다날의 SMS본인인증, KG이니시스 통합인증 지원

<Callout title="워드프레스 지원 결제대행사 목록 보러가기↗" />

#### **참고 연동가이드**

포트원을 통한 워드프레스 우커머스 플러그인 사용방법을 안내드립니다.

<Callout title="우커머스 플러그인 이용방법 보러가기↗" />
